<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:fhir="http://hl7.org/fhir"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


   <!--PROLOG-->
   <xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


   <!--KEYS AND FUNCTIONS-->


   <!--DEFAULT RULES-->


   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl" title="" schemaVersion="">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="http://hl7.org/fhir" prefix="fhir"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/XML/1998/namespace" prefix="xml"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-154</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-154</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M3"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-155</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-155</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M4"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-156</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-156</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M5"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-157</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-157</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M6"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-160</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-160</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M7"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-161</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-161</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M8"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-231</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-231</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M9"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-367</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-367</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M10"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-368</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-368</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M11"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-369</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-369</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M12"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-370</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-370</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M13"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-371</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-371</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M14"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-372</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-372</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M15"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-373</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-373</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M16"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-374</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-374</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M17"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-375</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-375</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M18"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-376</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-376</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M19"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-377</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-377</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M20"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-378</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-378</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M21"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-379</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-379</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M22"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-380</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-380</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M23"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-381</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-381</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M24"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-163</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-163</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M25"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-164</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-164</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M26"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-165</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-165</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M27"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-166</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-166</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M28"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-168</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-168</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M29"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-169</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-169</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M30"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-171</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-171</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M31"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-420</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-420</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M32"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-431</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-431</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M33"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-433</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-433</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M34"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-440</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-440</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M35"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


   <!--PATTERN onco-generic-dataelement-154-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']"
                 priority="1001"
                 mode="M3">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-154'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-154'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-154'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']/fhir:answer/*"
                 priority="1000"
                 mode="M3">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M3"/>
   <xsl:template match="@*|node()" priority="-2" mode="M3">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-155-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']"
                 priority="1001"
                 mode="M4">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-155'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-155'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-155'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']/fhir:answer/*"
                 priority="1000"
                 mode="M4">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueDate'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueDate'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueDate'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M4"/>
   <xsl:template match="@*|node()" priority="-2" mode="M4">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-156-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']"
                 priority="1001"
                 mode="M5">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-156'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-156'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-156'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']/fhir:answer/*"
                 priority="1000"
                 mode="M5">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M5"/>
   <xsl:template match="@*|node()" priority="-2" mode="M5">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-157-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']"
                 priority="1001"
                 mode="M6">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-157'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-157'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-157'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']/fhir:answer/*"
                 priority="1000"
                 mode="M6">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-generic-dataelement-157 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-generic-dataelement-157 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M6"/>
   <xsl:template match="@*|node()" priority="-2" mode="M6">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-160-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']"
                 priority="1001"
                 mode="M7">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-160'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-160'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-160'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']/fhir:answer/*"
                 priority="1000"
                 mode="M7">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueDate'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueDate'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueDate'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M7"/>
   <xsl:template match="@*|node()" priority="-2" mode="M7">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-161-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']"
                 priority="1001"
                 mode="M8">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-161'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-161'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-161'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']/fhir:answer/*"
                 priority="1000"
                 mode="M8">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M8"/>
   <xsl:template match="@*|node()" priority="-2" mode="M8">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-231-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']"
                 priority="1001"
                 mode="M9">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-231'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-231'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-231'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']/fhir:answer/*"
                 priority="1000"
                 mode="M9">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M9"/>
   <xsl:template match="@*|node()" priority="-2" mode="M9">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-367-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-367']"
                 priority="1001"
                 mode="M10">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-367']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-367'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-367'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-367'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-367']/fhir:answer/*"
                 priority="1000"
                 mode="M10">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-367']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M10"/>
   <xsl:template match="@*|node()" priority="-2" mode="M10">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-368-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-368']"
                 priority="1001"
                 mode="M11">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-368']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-368'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-368'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-368'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-368']/fhir:answer/*"
                 priority="1000"
                 mode="M11">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-368']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M11"/>
   <xsl:template match="@*|node()" priority="-2" mode="M11">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-369-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-369']"
                 priority="1001"
                 mode="M12">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-369']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-369'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-369'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-369'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-369']/fhir:answer/*"
                 priority="1000"
                 mode="M12">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-369']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.3--20160425120807', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.3--20160425120807</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-369 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.3--20160425120807.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.3--20160425120807</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-369 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.3--20160425120807.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M12"/>
   <xsl:template match="@*|node()" priority="-2" mode="M12">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-370-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-370']"
                 priority="1001"
                 mode="M13">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-370']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-370'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-370'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-370'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-370']/fhir:answer/*"
                 priority="1000"
                 mode="M13">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-370']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-370 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-370 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M13"/>
   <xsl:template match="@*|node()" priority="-2" mode="M13">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-371-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-371']"
                 priority="1001"
                 mode="M14">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-371']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-371'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-371'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-371'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-371']/fhir:answer/*"
                 priority="1000"
                 mode="M14">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-371']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.2--20151019115029', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.2--20151019115029</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-371 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.2--20151019115029.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.2--20151019115029</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-371 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.2--20151019115029.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M14"/>
   <xsl:template match="@*|node()" priority="-2" mode="M14">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-372-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-372']"
                 priority="1001"
                 mode="M15">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-372']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-372'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-372'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-372'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-372']/fhir:answer/*"
                 priority="1000"
                 mode="M15">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-372']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M15"/>
   <xsl:template match="@*|node()" priority="-2" mode="M15">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-373-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-373']"
                 priority="1001"
                 mode="M16">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-373']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-373'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-373'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-373'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-373']/fhir:answer/*"
                 priority="1000"
                 mode="M16">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-373']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-373 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-373 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M16"/>
   <xsl:template match="@*|node()" priority="-2" mode="M16">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-374-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-374']"
                 priority="1001"
                 mode="M17">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-374']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-374'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-374'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-374'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-374']/fhir:answer/*"
                 priority="1000"
                 mode="M17">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-374']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-374 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-374 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M17"/>
   <xsl:template match="@*|node()" priority="-2" mode="M17">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-375-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-375']"
                 priority="1001"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-375']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-375'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-375'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-375'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-375']/fhir:answer/*"
                 priority="1000"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-375']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M18"/>
   <xsl:template match="@*|node()" priority="-2" mode="M18">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-376-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-376']"
                 priority="1001"
                 mode="M19">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-376']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-376'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-376'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-376'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-376']/fhir:answer/*"
                 priority="1000"
                 mode="M19">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-376']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M19"/>
   <xsl:template match="@*|node()" priority="-2" mode="M19">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-377-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-377']"
                 priority="1001"
                 mode="M20">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-377']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-377'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-377'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-377'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-377']/fhir:answer/*"
                 priority="1000"
                 mode="M20">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-377']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-377 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-377 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M20"/>
   <xsl:template match="@*|node()" priority="-2" mode="M20">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-378-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-378']"
                 priority="1001"
                 mode="M21">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-378']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-378'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-378'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-378'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-378']/fhir:answer/*"
                 priority="1000"
                 mode="M21">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-378']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-378 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-378 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M21"/>
   <xsl:template match="@*|node()" priority="-2" mode="M21">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-379-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-379']"
                 priority="1001"
                 mode="M22">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-379']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-379'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-379'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-379'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-379']/fhir:answer/*"
                 priority="1000"
                 mode="M22">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-379']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M22"/>
   <xsl:template match="@*|node()" priority="-2" mode="M22">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-380-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-380']"
                 priority="1001"
                 mode="M23">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-380']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-380'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-380'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-380'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-380']/fhir:answer/*"
                 priority="1000"
                 mode="M23">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-380']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-380 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-380 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M23"/>
   <xsl:template match="@*|node()" priority="-2" mode="M23">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-381-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-381']"
                 priority="1001"
                 mode="M24">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-381']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-381'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-381'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-381'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-381']/fhir:answer/*"
                 priority="1000"
                 mode="M24">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-381']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-381 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-381 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M24"/>
   <xsl:template match="@*|node()" priority="-2" mode="M24">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-163-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']"
                 priority="1001"
                 mode="M25">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-163'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-163'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-163'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']/fhir:answer/*"
                 priority="1000"
                 mode="M25">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M25"/>
   <xsl:template match="@*|node()" priority="-2" mode="M25">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-164-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']"
                 priority="1001"
                 mode="M26">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-164'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-164'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-164'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']/fhir:answer/*"
                 priority="1000"
                 mode="M26">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-generic-dataelement-164 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-generic-dataelement-164 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M26"/>
   <xsl:template match="@*|node()" priority="-2" mode="M26">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-165-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']"
                 priority="1001"
                 mode="M27">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-165'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-165'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-165'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']/fhir:answer/*"
                 priority="1000"
                 mode="M27">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M27"/>
   <xsl:template match="@*|node()" priority="-2" mode="M27">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-166-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']"
                 priority="1001"
                 mode="M28">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-166'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-166'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-166'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']/fhir:answer/*"
                 priority="1000"
                 mode="M28">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M28"/>
   <xsl:template match="@*|node()" priority="-2" mode="M28">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-168-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']"
                 priority="1001"
                 mode="M29">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-168'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-168'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-168'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']/fhir:answer/*"
                 priority="1000"
                 mode="M29">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-generic-dataelement-168 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-generic-dataelement-168 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M29"/>
   <xsl:template match="@*|node()" priority="-2" mode="M29">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-169-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']"
                 priority="1001"
                 mode="M30">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-169'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-169'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-169'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']/fhir:answer/*"
                 priority="1000"
                 mode="M30">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M30"/>
   <xsl:template match="@*|node()" priority="-2" mode="M30">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-171-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-171']"
                 priority="1001"
                 mode="M31">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-171']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-171'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-171'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-171'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-171']/fhir:answer/*"
                 priority="1000"
                 mode="M31">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-171']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M31"/>
   <xsl:template match="@*|node()" priority="-2" mode="M31">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-420-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-420']"
                 priority="1001"
                 mode="M32">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-420']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-420'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-420'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-420'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-420']/fhir:answer/*"
                 priority="1000"
                 mode="M32">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-420']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M32"/>
   <xsl:template match="@*|node()" priority="-2" mode="M32">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-431-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-431']"
                 priority="1001"
                 mode="M33">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-431']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-431'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-431'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-431'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-431']/fhir:answer/*"
                 priority="1000"
                 mode="M33">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-431']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M33"/>
   <xsl:template match="@*|node()" priority="-2" mode="M33">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-433-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-433']"
                 priority="1001"
                 mode="M34">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-433']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-433'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-433'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-433'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-433']/fhir:answer/*"
                 priority="1000"
                 mode="M34">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-433']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-433 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-433 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M34"/>
   <xsl:template match="@*|node()" priority="-2" mode="M34">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-440-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-440']"
                 priority="1001"
                 mode="M35">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-440']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-440'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-440'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-440'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-440']/fhir:answer/*"
                 priority="1000"
                 mode="M35">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-440']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-440 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-440 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M35"/>
   <xsl:template match="@*|node()" priority="-2" mode="M35">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>
</xsl:stylesheet>
