<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:fhir="http://hl7.org/fhir"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


   <!--PROLOG-->
   <xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


   <!--KEYS AND FUNCTIONS-->


   <!--DEFAULT RULES-->


   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl" title="" schemaVersion="">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="http://hl7.org/fhir" prefix="fhir"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/XML/1998/namespace" prefix="xml"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-81</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-81</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M3"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-119</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-119</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M4"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-125</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-125</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M5"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-80</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-80</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M6"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-81</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-81</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M7"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-82</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-82</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M8"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-83</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-83</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M9"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-126</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-126</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M10"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-88</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-88</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M11"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-89</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-89</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M12"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-90</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-90</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M13"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-91</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-91</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M14"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-92</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-92</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M15"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-94</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-94</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M16"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-95</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-95</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M17"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-96</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-96</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M18"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-97</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-97</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M19"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-98</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-98</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M20"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-99</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-99</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M21"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-100</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-100</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M22"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-101</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-101</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M23"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-102</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-102</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M24"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-103</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-103</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M25"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-104</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-104</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M26"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-105</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-105</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M27"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-106</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-106</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M28"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-107</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-107</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M29"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-108</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-108</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M30"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-109</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-109</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M31"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-110</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-110</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M32"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-111</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-111</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M33"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-112</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-112</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M34"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-113</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-113</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M35"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-114</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-114</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M36"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-115</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-115</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M37"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-127</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-127</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M38"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-139</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-139</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M39"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-176</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-176</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M40"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-178</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-178</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M41"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-180</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-180</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M42"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-181</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-181</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M43"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-182</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-182</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M44"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-183</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-183</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M45"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-184</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-184</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M46"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-185</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-185</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M47"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-145</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-145</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M48"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-192</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-192</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M49"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-193</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-193</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M50"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-194</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-194</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M51"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-195</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-195</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M52"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-196</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-196</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M53"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-197</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-197</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M54"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-198</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-198</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M55"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-199</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-199</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M56"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-200</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-200</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M57"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-201</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-201</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M58"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-202</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-202</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M59"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-146</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-146</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M60"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-205</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-205</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M61"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-206</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-206</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M62"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-208</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-208</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M63"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-209</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-209</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M64"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-210</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-210</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M65"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-211</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-211</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M66"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-212</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-212</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M67"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-213</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-213</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M68"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-214</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-214</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M69"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-215</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-215</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M70"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-216</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-216</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M71"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-217</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-217</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M72"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-218</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-218</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M73"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-219</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-219</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M74"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-220</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-220</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M75"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-221</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-221</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M76"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-222</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-222</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M77"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-154</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-154</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M78"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-155</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-155</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M79"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-156</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-156</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M80"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-157</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-157</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M81"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-160</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-160</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M82"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-161</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-161</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M83"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-231</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-231</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M84"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-232</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-232</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M85"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-234</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-234</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M86"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-239</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-239</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M87"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-240</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-240</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M88"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-241</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-241</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M89"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-242</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-242</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M90"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-244</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-244</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M91"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-245</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-245</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M92"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-246</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-246</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M93"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-247</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-247</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M94"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-248</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-248</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M95"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-249</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-249</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M96"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-250</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-250</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M97"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-251</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-251</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M98"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-252</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-252</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M99"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-253</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-253</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M100"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-254</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-254</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M101"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-255</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-255</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M102"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-256</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-256</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M103"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-257</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-257</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M104"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-258</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-258</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M105"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-259</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-259</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M106"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-260</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-260</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M107"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-261</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-261</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M108"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-262</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-262</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M109"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-263</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-263</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M110"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-264</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-264</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M111"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-265</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-265</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M112"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-266</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-266</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M113"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-267</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-267</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M114"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-268</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-268</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M115"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-269</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-269</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M116"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-270</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-270</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M117"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-271</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-271</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M118"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-272</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-272</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M119"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-273</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-273</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M120"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-274</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-274</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M121"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-163</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-163</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M122"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-164</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-164</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M123"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-165</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-165</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M124"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-166</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-166</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M125"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-168</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-168</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M126"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-169</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-169</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M127"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


   <!--PATTERN onco-generic-dataelement-81-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-81']"
                 priority="1001"
                 mode="M3">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-81'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-81'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-81'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-81']/fhir:answer/*"
                 priority="1000"
                 mode="M3">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M3"/>
   <xsl:template match="@*|node()" priority="-2" mode="M3">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-119-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-119']"
                 priority="1001"
                 mode="M4">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-119'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-119'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-119'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-119']/fhir:answer/*"
                 priority="1000"
                 mode="M4">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M4"/>
   <xsl:template match="@*|node()" priority="-2" mode="M4">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-125-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-125']"
                 priority="1001"
                 mode="M5">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-125'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-125'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-125'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-125']/fhir:answer/*"
                 priority="1000"
                 mode="M5">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'value'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="local-name(.) = 'value'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'value'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M5"/>
   <xsl:template match="@*|node()" priority="-2" mode="M5">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-80-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-80']"
                 priority="1001"
                 mode="M6">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-80'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-80'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-80'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-80']/fhir:answer/*"
                 priority="1000"
                 mode="M6">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M6"/>
   <xsl:template match="@*|node()" priority="-2" mode="M6">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-81-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-81']"
                 priority="1001"
                 mode="M7">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-81'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-81'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-81'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-81']/fhir:answer/*"
                 priority="1000"
                 mode="M7">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-81 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-81 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M7"/>
   <xsl:template match="@*|node()" priority="-2" mode="M7">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-82-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-82']"
                 priority="1001"
                 mode="M8">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-82'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-82'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-82'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-82']/fhir:answer/*"
                 priority="1000"
                 mode="M8">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-82 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-82 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M8"/>
   <xsl:template match="@*|node()" priority="-2" mode="M8">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-83-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-83']"
                 priority="1001"
                 mode="M9">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-83'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-83'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-83'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-83']/fhir:answer/*"
                 priority="1000"
                 mode="M9">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.14--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.14--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-83 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.14--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.14--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-83 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.14--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M9"/>
   <xsl:template match="@*|node()" priority="-2" mode="M9">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-126-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-126']"
                 priority="1001"
                 mode="M10">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-126'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-126'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-126'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-126']/fhir:answer/*"
                 priority="1000"
                 mode="M10">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'value'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="local-name(.) = 'value'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'value'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M10"/>
   <xsl:template match="@*|node()" priority="-2" mode="M10">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-88-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-88']"
                 priority="1001"
                 mode="M11">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-88'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-88'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-88'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-88']/fhir:answer/*"
                 priority="1000"
                 mode="M11">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M11"/>
   <xsl:template match="@*|node()" priority="-2" mode="M11">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-89-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-89']"
                 priority="1001"
                 mode="M12">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-89'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-89'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-89'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-89']/fhir:answer/*"
                 priority="1000"
                 mode="M12">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M12"/>
   <xsl:template match="@*|node()" priority="-2" mode="M12">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-90-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-90']"
                 priority="1001"
                 mode="M13">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-90'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-90'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-90'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-90']/fhir:answer/*"
                 priority="1000"
                 mode="M13">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M13"/>
   <xsl:template match="@*|node()" priority="-2" mode="M13">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-91-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-91']"
                 priority="1001"
                 mode="M14">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-91'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-91'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-91'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-91']/fhir:answer/*"
                 priority="1000"
                 mode="M14">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-91 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-91 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M14"/>
   <xsl:template match="@*|node()" priority="-2" mode="M14">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-92-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-92']"
                 priority="1001"
                 mode="M15">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-92'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-92'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-92'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-92']/fhir:answer/*"
                 priority="1000"
                 mode="M15">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-92 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-92 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M15"/>
   <xsl:template match="@*|node()" priority="-2" mode="M15">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-94-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-94']"
                 priority="1001"
                 mode="M16">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-94'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-94'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-94'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-94']/fhir:answer/*"
                 priority="1000"
                 mode="M16">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M16"/>
   <xsl:template match="@*|node()" priority="-2" mode="M16">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-95-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-95']"
                 priority="1001"
                 mode="M17">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-95'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-95'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-95'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-95']/fhir:answer/*"
                 priority="1000"
                 mode="M17">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.1--20160817133546', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.1--20160817133546</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-95 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.1--20160817133546.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.1--20160817133546</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-95 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.1--20160817133546.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M17"/>
   <xsl:template match="@*|node()" priority="-2" mode="M17">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-96-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-96']"
                 priority="1001"
                 mode="M18">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-96'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-96'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-96'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-96']/fhir:answer/*"
                 priority="1000"
                 mode="M18">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-96 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-96 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M18"/>
   <xsl:template match="@*|node()" priority="-2" mode="M18">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-97-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-97']"
                 priority="1001"
                 mode="M19">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-97'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-97'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-97'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-97']/fhir:answer/*"
                 priority="1000"
                 mode="M19">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-97 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-97 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M19"/>
   <xsl:template match="@*|node()" priority="-2" mode="M19">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-98-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-98']"
                 priority="1001"
                 mode="M20">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-98'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-98'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-98'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-98']/fhir:answer/*"
                 priority="1000"
                 mode="M20">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.40--20160817135741', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.40--20160817135741</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-98 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.40--20160817135741.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.40--20160817135741</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-98 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.40--20160817135741.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M20"/>
   <xsl:template match="@*|node()" priority="-2" mode="M20">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-99-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-99']"
                 priority="1001"
                 mode="M21">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-99'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-99'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-99'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-99']/fhir:answer/*"
                 priority="1000"
                 mode="M21">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.28--20160817134744', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.28--20160817134744</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-99 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.28--20160817134744.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.28--20160817134744</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-99 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.28--20160817134744.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M21"/>
   <xsl:template match="@*|node()" priority="-2" mode="M21">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-100-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-100']"
                 priority="1001"
                 mode="M22">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-100'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-100'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-100'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-100']/fhir:answer/*"
                 priority="1000"
                 mode="M22">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.43--20160817140242', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.43--20160817140242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-100 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.43--20160817140242.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.43--20160817140242</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-100 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.43--20160817140242.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M22"/>
   <xsl:template match="@*|node()" priority="-2" mode="M22">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-101-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-101']"
                 priority="1001"
                 mode="M23">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-101'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-101'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-101'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-101']/fhir:answer/*"
                 priority="1000"
                 mode="M23">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.20--20160817141204', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.20--20160817141204</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-101 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.20--20160817141204.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.20--20160817141204</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-101 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.20--20160817141204.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M23"/>
   <xsl:template match="@*|node()" priority="-2" mode="M23">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-102-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-102']"
                 priority="1001"
                 mode="M24">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-102'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-102'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-102'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-102']/fhir:answer/*"
                 priority="1000"
                 mode="M24">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-102 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-102 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M24"/>
   <xsl:template match="@*|node()" priority="-2" mode="M24">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-103-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-103']"
                 priority="1001"
                 mode="M25">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-103'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-103'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-103'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-103']/fhir:answer/*"
                 priority="1000"
                 mode="M25">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.11--20160817141547', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.11--20160817141547</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-103 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.11--20160817141547.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.11--20160817141547</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-103 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.11--20160817141547.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M25"/>
   <xsl:template match="@*|node()" priority="-2" mode="M25">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-104-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-104']"
                 priority="1001"
                 mode="M26">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-104'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-104'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-104'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-104']/fhir:answer/*"
                 priority="1000"
                 mode="M26">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-104 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-104 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M26"/>
   <xsl:template match="@*|node()" priority="-2" mode="M26">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-105-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-105']"
                 priority="1001"
                 mode="M27">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-105'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-105'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-105'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-105']/fhir:answer/*"
                 priority="1000"
                 mode="M27">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M27"/>
   <xsl:template match="@*|node()" priority="-2" mode="M27">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-106-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-106']"
                 priority="1001"
                 mode="M28">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-106'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-106'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-106'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-106']/fhir:answer/*"
                 priority="1000"
                 mode="M28">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.54--20150605090932', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.54--20150605090932</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-106 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.54--20150605090932.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.54--20150605090932</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-106 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.54--20150605090932.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M28"/>
   <xsl:template match="@*|node()" priority="-2" mode="M28">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-107-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-107']"
                 priority="1001"
                 mode="M29">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-107'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-107'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-107'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-107']/fhir:answer/*"
                 priority="1000"
                 mode="M29">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M29"/>
   <xsl:template match="@*|node()" priority="-2" mode="M29">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-108-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-108']"
                 priority="1001"
                 mode="M30">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-108'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-108'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-108'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-108']/fhir:answer/*"
                 priority="1000"
                 mode="M30">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.23--20150605091229', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.23--20150605091229</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-108 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.23--20150605091229.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.23--20150605091229</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-108 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.23--20150605091229.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M30"/>
   <xsl:template match="@*|node()" priority="-2" mode="M30">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-109-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-109']"
                 priority="1001"
                 mode="M31">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-109'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-109'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-109'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-109']/fhir:answer/*"
                 priority="1000"
                 mode="M31">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M31"/>
   <xsl:template match="@*|node()" priority="-2" mode="M31">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-110-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-110']"
                 priority="1001"
                 mode="M32">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-110'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-110'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-110'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-110']/fhir:answer/*"
                 priority="1000"
                 mode="M32">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-110 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-110 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M32"/>
   <xsl:template match="@*|node()" priority="-2" mode="M32">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-111-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-111']"
                 priority="1001"
                 mode="M33">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-111'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-111'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-111'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-111']/fhir:answer/*"
                 priority="1000"
                 mode="M33">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.15--20160105173142', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.15--20160105173142</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-111 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.15--20160105173142.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.15--20160105173142</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-111 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.15--20160105173142.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M33"/>
   <xsl:template match="@*|node()" priority="-2" mode="M33">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-112-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-112']"
                 priority="1001"
                 mode="M34">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-112'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-112'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-112'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-112']/fhir:answer/*"
                 priority="1000"
                 mode="M34">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.17--20160105173642', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.17--20160105173642</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-112 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.17--20160105173642.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.17--20160105173642</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-112 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.17--20160105173642.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M34"/>
   <xsl:template match="@*|node()" priority="-2" mode="M34">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-113-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-113']"
                 priority="1001"
                 mode="M35">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-113'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-113'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-113'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-113']/fhir:answer/*"
                 priority="1000"
                 mode="M35">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.17--20160105173642', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.17--20160105173642</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-113 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.17--20160105173642.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.17--20160105173642</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-113 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.17--20160105173642.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M35"/>
   <xsl:template match="@*|node()" priority="-2" mode="M35">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-114-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-114']"
                 priority="1001"
                 mode="M36">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-114'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-114'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-114'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-114']/fhir:answer/*"
                 priority="1000"
                 mode="M36">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.5--20160817145921', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.5--20160817145921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-114 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.5--20160817145921.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.5--20160817145921</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-114 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.5--20160817145921.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M36"/>
   <xsl:template match="@*|node()" priority="-2" mode="M36">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-115-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-115']"
                 priority="1001"
                 mode="M37">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-115'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-115'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-115'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-115']/fhir:answer/*"
                 priority="1000"
                 mode="M37">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.4--20160817150324', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.4--20160817150324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-115 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.4--20160817150324.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.4--20160817150324</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-115 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.4--20160817150324.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M37"/>
   <xsl:template match="@*|node()" priority="-2" mode="M37">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-127-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-127']"
                 priority="1001"
                 mode="M38">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-127'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-127'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-127'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-127']/fhir:answer/*"
                 priority="1000"
                 mode="M38">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M38"/>
   <xsl:template match="@*|node()" priority="-2" mode="M38">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-139-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-139']"
                 priority="1001"
                 mode="M39">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-139'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-139'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-139'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-139']/fhir:answer/*"
                 priority="1000"
                 mode="M39">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M39"/>
   <xsl:template match="@*|node()" priority="-2" mode="M39">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-176-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-176']"
                 priority="1001"
                 mode="M40">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-176'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-176'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-176'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-176']/fhir:answer/*"
                 priority="1000"
                 mode="M40">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M40"/>
   <xsl:template match="@*|node()" priority="-2" mode="M40">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-178-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-178']"
                 priority="1001"
                 mode="M41">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-178'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-178'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-178'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-178']/fhir:answer/*"
                 priority="1000"
                 mode="M41">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-178 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-178 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M41"/>
   <xsl:template match="@*|node()" priority="-2" mode="M41">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-180-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-180']"
                 priority="1001"
                 mode="M42">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-180'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-180'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-180'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-180']/fhir:answer/*"
                 priority="1000"
                 mode="M42">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M42"/>
   <xsl:template match="@*|node()" priority="-2" mode="M42">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-181-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-181']"
                 priority="1001"
                 mode="M43">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-181'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-181'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-181'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-181']/fhir:answer/*"
                 priority="1000"
                 mode="M43">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-181 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-181 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M43"/>
   <xsl:template match="@*|node()" priority="-2" mode="M43">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-182-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-182']"
                 priority="1001"
                 mode="M44">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-182'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-182'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-182'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M44"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-182']/fhir:answer/*"
                 priority="1000"
                 mode="M44">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-182 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-182 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M44"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M44"/>
   <xsl:template match="@*|node()" priority="-2" mode="M44">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M44"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-183-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-183']"
                 priority="1001"
                 mode="M45">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-183'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-183'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-183'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M45"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-183']/fhir:answer/*"
                 priority="1000"
                 mode="M45">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M45"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M45"/>
   <xsl:template match="@*|node()" priority="-2" mode="M45">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M45"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-184-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-184']"
                 priority="1001"
                 mode="M46">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-184'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-184'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-184'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M46"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-184']/fhir:answer/*"
                 priority="1000"
                 mode="M46">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-184 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-184 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M46"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M46"/>
   <xsl:template match="@*|node()" priority="-2" mode="M46">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M46"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-185-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-185']"
                 priority="1001"
                 mode="M47">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-185'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-185'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-185'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M47"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-185']/fhir:answer/*"
                 priority="1000"
                 mode="M47">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-185 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-185 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M47"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M47"/>
   <xsl:template match="@*|node()" priority="-2" mode="M47">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M47"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-145-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-145']"
                 priority="1001"
                 mode="M48">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-145'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-145'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-145'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M48"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-145']/fhir:answer/*"
                 priority="1000"
                 mode="M48">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'value'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="local-name(.) = 'value'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'value'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M48"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M48"/>
   <xsl:template match="@*|node()" priority="-2" mode="M48">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M48"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-192-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-192']"
                 priority="1001"
                 mode="M49">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-192'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-192'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-192'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M49"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-192']/fhir:answer/*"
                 priority="1000"
                 mode="M49">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M49"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M49"/>
   <xsl:template match="@*|node()" priority="-2" mode="M49">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M49"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-193-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-193']"
                 priority="1001"
                 mode="M50">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-193'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-193'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-193'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M50"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-193']/fhir:answer/*"
                 priority="1000"
                 mode="M50">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-193 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-193 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M50"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M50"/>
   <xsl:template match="@*|node()" priority="-2" mode="M50">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M50"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-194-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-194']"
                 priority="1001"
                 mode="M51">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-194'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-194'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-194'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M51"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-194']/fhir:answer/*"
                 priority="1000"
                 mode="M51">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M51"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M51"/>
   <xsl:template match="@*|node()" priority="-2" mode="M51">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M51"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-195-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-195']"
                 priority="1001"
                 mode="M52">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-195'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-195'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-195'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M52"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-195']/fhir:answer/*"
                 priority="1000"
                 mode="M52">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-195 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-195 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M52"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M52"/>
   <xsl:template match="@*|node()" priority="-2" mode="M52">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M52"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-196-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-196']"
                 priority="1001"
                 mode="M53">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-196'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-196'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-196'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M53"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-196']/fhir:answer/*"
                 priority="1000"
                 mode="M53">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-196 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-196 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M53"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M53"/>
   <xsl:template match="@*|node()" priority="-2" mode="M53">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M53"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-197-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-197']"
                 priority="1001"
                 mode="M54">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-197'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-197'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-197'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M54"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-197']/fhir:answer/*"
                 priority="1000"
                 mode="M54">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M54"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M54"/>
   <xsl:template match="@*|node()" priority="-2" mode="M54">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M54"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-198-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-198']"
                 priority="1001"
                 mode="M55">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-198'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-198'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-198'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M55"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-198']/fhir:answer/*"
                 priority="1000"
                 mode="M55">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-198 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-198 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M55"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M55"/>
   <xsl:template match="@*|node()" priority="-2" mode="M55">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M55"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-199-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-199']"
                 priority="1001"
                 mode="M56">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-199'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-199'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-199'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M56"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-199']/fhir:answer/*"
                 priority="1000"
                 mode="M56">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-199 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-199 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M56"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M56"/>
   <xsl:template match="@*|node()" priority="-2" mode="M56">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M56"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-200-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-200']"
                 priority="1001"
                 mode="M57">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-200'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-200'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-200'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M57"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-200']/fhir:answer/*"
                 priority="1000"
                 mode="M57">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M57"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M57"/>
   <xsl:template match="@*|node()" priority="-2" mode="M57">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M57"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-201-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-201']"
                 priority="1001"
                 mode="M58">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-201'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-201'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-201'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M58"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-201']/fhir:answer/*"
                 priority="1000"
                 mode="M58">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-201 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-201 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M58"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M58"/>
   <xsl:template match="@*|node()" priority="-2" mode="M58">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M58"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-202-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-202']"
                 priority="1001"
                 mode="M59">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-202'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-202'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-202'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M59"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-202']/fhir:answer/*"
                 priority="1000"
                 mode="M59">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-202 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-202 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M59"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M59"/>
   <xsl:template match="@*|node()" priority="-2" mode="M59">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M59"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-146-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-146']"
                 priority="1001"
                 mode="M60">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-146'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-146'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-146'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M60"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-146']/fhir:answer/*"
                 priority="1000"
                 mode="M60">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M60"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M60"/>
   <xsl:template match="@*|node()" priority="-2" mode="M60">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M60"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-205-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-205']"
                 priority="1001"
                 mode="M61">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-205'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-205'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-205'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M61"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-205']/fhir:answer/*"
                 priority="1000"
                 mode="M61">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M61"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M61"/>
   <xsl:template match="@*|node()" priority="-2" mode="M61">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M61"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-206-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-206']"
                 priority="1001"
                 mode="M62">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-206'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-206'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-206'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M62"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-206']/fhir:answer/*"
                 priority="1000"
                 mode="M62">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-206 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-206 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M62"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M62"/>
   <xsl:template match="@*|node()" priority="-2" mode="M62">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M62"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-208-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-208']"
                 priority="1001"
                 mode="M63">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-208'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-208'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-208'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M63"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-208']/fhir:answer/*"
                 priority="1000"
                 mode="M63">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-208 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-208 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M63"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M63"/>
   <xsl:template match="@*|node()" priority="-2" mode="M63">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M63"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-209-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-209']"
                 priority="1001"
                 mode="M64">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-209'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-209'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-209'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M64"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-209']/fhir:answer/*"
                 priority="1000"
                 mode="M64">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-209 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-209 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M64"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M64"/>
   <xsl:template match="@*|node()" priority="-2" mode="M64">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M64"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-210-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-210']"
                 priority="1001"
                 mode="M65">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-210'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-210'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-210'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M65"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-210']/fhir:answer/*"
                 priority="1000"
                 mode="M65">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-210 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-210 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M65"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M65"/>
   <xsl:template match="@*|node()" priority="-2" mode="M65">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M65"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-211-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-211']"
                 priority="1001"
                 mode="M66">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-211'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-211'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-211'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M66"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-211']/fhir:answer/*"
                 priority="1000"
                 mode="M66">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-211 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-211 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M66"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M66"/>
   <xsl:template match="@*|node()" priority="-2" mode="M66">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M66"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-212-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-212']"
                 priority="1001"
                 mode="M67">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-212'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-212'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-212'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M67"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-212']/fhir:answer/*"
                 priority="1000"
                 mode="M67">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-212 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-212 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M67"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M67"/>
   <xsl:template match="@*|node()" priority="-2" mode="M67">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M67"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-213-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-213']"
                 priority="1001"
                 mode="M68">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-213'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-213'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-213'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M68"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-213']/fhir:answer/*"
                 priority="1000"
                 mode="M68">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.35--20150714070650', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.35--20150714070650</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-213 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.35--20150714070650.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.35--20150714070650</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-213 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.35--20150714070650.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M68"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M68"/>
   <xsl:template match="@*|node()" priority="-2" mode="M68">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M68"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-214-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-214']"
                 priority="1001"
                 mode="M69">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-214'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-214'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-214'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M69"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-214']/fhir:answer/*"
                 priority="1000"
                 mode="M69">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.55--20150609145924', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.55--20150609145924</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-214 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.55--20150609145924.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.55--20150609145924</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-214 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.55--20150609145924.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M69"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M69"/>
   <xsl:template match="@*|node()" priority="-2" mode="M69">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M69"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-215-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-215']"
                 priority="1001"
                 mode="M70">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-215'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-215'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-215'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M70"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-215']/fhir:answer/*"
                 priority="1000"
                 mode="M70">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-215 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-215 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M70"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M70"/>
   <xsl:template match="@*|node()" priority="-2" mode="M70">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M70"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-216-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-216']"
                 priority="1001"
                 mode="M71">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-216'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-216'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-216'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M71"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-216']/fhir:answer/*"
                 priority="1000"
                 mode="M71">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M71"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M71"/>
   <xsl:template match="@*|node()" priority="-2" mode="M71">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M71"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-217-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-217']"
                 priority="1001"
                 mode="M72">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-217'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-217'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-217'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M72"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-217']/fhir:answer/*"
                 priority="1000"
                 mode="M72">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.22--20150707193518', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.22--20150707193518</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-217 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.22--20150707193518.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.22--20150707193518</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-217 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.22--20150707193518.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M72"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M72"/>
   <xsl:template match="@*|node()" priority="-2" mode="M72">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M72"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-218-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-218']"
                 priority="1001"
                 mode="M73">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-218'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-218'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-218'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M73"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-218']/fhir:answer/*"
                 priority="1000"
                 mode="M73">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-218 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-218 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.31--20150704090625.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M73"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M73"/>
   <xsl:template match="@*|node()" priority="-2" mode="M73">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M73"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-219-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-219']"
                 priority="1001"
                 mode="M74">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-219'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-219'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-219'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M74"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-219']/fhir:answer/*"
                 priority="1000"
                 mode="M74">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-219 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-219 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M74"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M74"/>
   <xsl:template match="@*|node()" priority="-2" mode="M74">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M74"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-220-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-220']"
                 priority="1001"
                 mode="M75">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-220'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-220'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-220'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M75"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-220']/fhir:answer/*"
                 priority="1000"
                 mode="M75">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M75"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M75"/>
   <xsl:template match="@*|node()" priority="-2" mode="M75">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M75"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-221-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-221']"
                 priority="1001"
                 mode="M76">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-221'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-221'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-221'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M76"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-221']/fhir:answer/*"
                 priority="1000"
                 mode="M76">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-221 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-221 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M76"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M76"/>
   <xsl:template match="@*|node()" priority="-2" mode="M76">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M76"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-222-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-222']"
                 priority="1001"
                 mode="M77">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-222'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-222'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-222'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M77"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-222']/fhir:answer/*"
                 priority="1000"
                 mode="M77">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-222 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-222 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M77"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M77"/>
   <xsl:template match="@*|node()" priority="-2" mode="M77">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M77"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-154-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']"
                 priority="1001"
                 mode="M78">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-154'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-154'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-154'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M78"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']/fhir:answer/*"
                 priority="1000"
                 mode="M78">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M78"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M78"/>
   <xsl:template match="@*|node()" priority="-2" mode="M78">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M78"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-155-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']"
                 priority="1001"
                 mode="M79">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-155'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-155'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-155'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M79"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']/fhir:answer/*"
                 priority="1000"
                 mode="M79">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueDate'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueDate'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueDate'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M79"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M79"/>
   <xsl:template match="@*|node()" priority="-2" mode="M79">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M79"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-156-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']"
                 priority="1001"
                 mode="M80">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-156'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-156'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-156'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M80"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']/fhir:answer/*"
                 priority="1000"
                 mode="M80">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M80"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M80"/>
   <xsl:template match="@*|node()" priority="-2" mode="M80">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M80"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-157-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']"
                 priority="1001"
                 mode="M81">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-157'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-157'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-157'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M81"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']/fhir:answer/*"
                 priority="1000"
                 mode="M81">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-generic-dataelement-157 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-generic-dataelement-157 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M81"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M81"/>
   <xsl:template match="@*|node()" priority="-2" mode="M81">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M81"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-160-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']"
                 priority="1001"
                 mode="M82">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-160'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-160'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-160'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M82"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']/fhir:answer/*"
                 priority="1000"
                 mode="M82">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueDate'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueDate'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueDate'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M82"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M82"/>
   <xsl:template match="@*|node()" priority="-2" mode="M82">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M82"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-161-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']"
                 priority="1001"
                 mode="M83">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-161'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-161'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-161'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M83"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']/fhir:answer/*"
                 priority="1000"
                 mode="M83">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M83"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M83"/>
   <xsl:template match="@*|node()" priority="-2" mode="M83">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M83"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-231-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']"
                 priority="1001"
                 mode="M84">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-231'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-231'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-231'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M84"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']/fhir:answer/*"
                 priority="1000"
                 mode="M84">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M84"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M84"/>
   <xsl:template match="@*|node()" priority="-2" mode="M84">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M84"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-232-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-232']"
                 priority="1001"
                 mode="M85">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-232'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-232'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-232'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M85"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-232']/fhir:answer/*"
                 priority="1000"
                 mode="M85">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M85"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M85"/>
   <xsl:template match="@*|node()" priority="-2" mode="M85">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M85"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-234-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-234']"
                 priority="1001"
                 mode="M86">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-234'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-234'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-234'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M86"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-234']/fhir:answer/*"
                 priority="1000"
                 mode="M86">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-234 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-234 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M86"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M86"/>
   <xsl:template match="@*|node()" priority="-2" mode="M86">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M86"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-239-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-239']"
                 priority="1001"
                 mode="M87">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-239'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-239'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-239'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M87"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-239']/fhir:answer/*"
                 priority="1000"
                 mode="M87">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M87"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M87"/>
   <xsl:template match="@*|node()" priority="-2" mode="M87">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M87"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-240-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-240']"
                 priority="1001"
                 mode="M88">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-240'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-240'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-240'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M88"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-240']/fhir:answer/*"
                 priority="1000"
                 mode="M88">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-240 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-240 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M88"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M88"/>
   <xsl:template match="@*|node()" priority="-2" mode="M88">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M88"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-241-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-241']"
                 priority="1001"
                 mode="M89">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-241'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-241'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-241'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M89"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-241']/fhir:answer/*"
                 priority="1000"
                 mode="M89">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-241 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-241 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.8--20150716070243.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M89"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M89"/>
   <xsl:template match="@*|node()" priority="-2" mode="M89">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M89"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-242-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-242']"
                 priority="1001"
                 mode="M90">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-242'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-242'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-242'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M90"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-242']/fhir:answer/*"
                 priority="1000"
                 mode="M90">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-242 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-242 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M90"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M90"/>
   <xsl:template match="@*|node()" priority="-2" mode="M90">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M90"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-244-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-244']"
                 priority="1001"
                 mode="M91">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-244'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-244'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-244'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M91"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-244']/fhir:answer/*"
                 priority="1000"
                 mode="M91">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-244 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-244 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M91"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M91"/>
   <xsl:template match="@*|node()" priority="-2" mode="M91">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M91"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-245-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-245']"
                 priority="1001"
                 mode="M92">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-245'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-245'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-245'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M92"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-245']/fhir:answer/*"
                 priority="1000"
                 mode="M92">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-245 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-245 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M92"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M92"/>
   <xsl:template match="@*|node()" priority="-2" mode="M92">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M92"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-246-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-246']"
                 priority="1001"
                 mode="M93">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-246'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-246'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-246'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M93"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-246']/fhir:answer/*"
                 priority="1000"
                 mode="M93">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M93"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M93"/>
   <xsl:template match="@*|node()" priority="-2" mode="M93">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M93"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-247-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-247']"
                 priority="1001"
                 mode="M94">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-247'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-247'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-247'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M94"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-247']/fhir:answer/*"
                 priority="1000"
                 mode="M94">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M94"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M94"/>
   <xsl:template match="@*|node()" priority="-2" mode="M94">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M94"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-248-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-248']"
                 priority="1001"
                 mode="M95">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-248'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-248'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-248'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M95"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-248']/fhir:answer/*"
                 priority="1000"
                 mode="M95">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-248 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-248 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M95"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M95"/>
   <xsl:template match="@*|node()" priority="-2" mode="M95">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M95"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-249-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-249']"
                 priority="1001"
                 mode="M96">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-249'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-249'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-249'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M96"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-249']/fhir:answer/*"
                 priority="1000"
                 mode="M96">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-249 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-249 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.34--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M96"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M96"/>
   <xsl:template match="@*|node()" priority="-2" mode="M96">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M96"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-250-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-250']"
                 priority="1001"
                 mode="M97">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-250'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-250'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-250'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M97"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-250']/fhir:answer/*"
                 priority="1000"
                 mode="M97">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-250 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-250 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M97"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M97"/>
   <xsl:template match="@*|node()" priority="-2" mode="M97">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M97"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-251-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-251']"
                 priority="1001"
                 mode="M98">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-251'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-251'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-251'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M98"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-251']/fhir:answer/*"
                 priority="1000"
                 mode="M98">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M98"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M98"/>
   <xsl:template match="@*|node()" priority="-2" mode="M98">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M98"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-252-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-252']"
                 priority="1001"
                 mode="M99">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-252'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-252'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-252'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M99"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-252']/fhir:answer/*"
                 priority="1000"
                 mode="M99">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-252 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-252 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M99"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M99"/>
   <xsl:template match="@*|node()" priority="-2" mode="M99">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M99"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-253-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-253']"
                 priority="1001"
                 mode="M100">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-253'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-253'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-253'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M100"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-253']/fhir:answer/*"
                 priority="1000"
                 mode="M100">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-253 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-253 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M100"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M100"/>
   <xsl:template match="@*|node()" priority="-2" mode="M100">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M100"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-254-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-254']"
                 priority="1001"
                 mode="M101">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-254'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-254'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-254'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M101"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-254']/fhir:answer/*"
                 priority="1000"
                 mode="M101">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-254 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-254 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M101"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M101"/>
   <xsl:template match="@*|node()" priority="-2" mode="M101">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M101"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-255-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-255']"
                 priority="1001"
                 mode="M102">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-255'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-255'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-255'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M102"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-255']/fhir:answer/*"
                 priority="1000"
                 mode="M102">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-255 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-255 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M102"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M102"/>
   <xsl:template match="@*|node()" priority="-2" mode="M102">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M102"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-256-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-256']"
                 priority="1001"
                 mode="M103">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-256'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-256'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-256'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M103"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-256']/fhir:answer/*"
                 priority="1000"
                 mode="M103">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M103"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M103"/>
   <xsl:template match="@*|node()" priority="-2" mode="M103">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M103"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-257-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-257']"
                 priority="1001"
                 mode="M104">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-257'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-257'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-257'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M104"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-257']/fhir:answer/*"
                 priority="1000"
                 mode="M104">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M104"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M104"/>
   <xsl:template match="@*|node()" priority="-2" mode="M104">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M104"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-258-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-258']"
                 priority="1001"
                 mode="M105">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-258'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-258'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-258'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M105"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-258']/fhir:answer/*"
                 priority="1000"
                 mode="M105">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M105"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M105"/>
   <xsl:template match="@*|node()" priority="-2" mode="M105">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M105"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-259-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-259']"
                 priority="1001"
                 mode="M106">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-259'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-259'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-259'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M106"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-259']/fhir:answer/*"
                 priority="1000"
                 mode="M106">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-259 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-259 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M106"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M106"/>
   <xsl:template match="@*|node()" priority="-2" mode="M106">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M106"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-260-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-260']"
                 priority="1001"
                 mode="M107">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-260'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-260'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-260'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M107"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-260']/fhir:answer/*"
                 priority="1000"
                 mode="M107">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M107"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M107"/>
   <xsl:template match="@*|node()" priority="-2" mode="M107">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M107"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-261-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-261']"
                 priority="1001"
                 mode="M108">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-261'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-261'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-261'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M108"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-261']/fhir:answer/*"
                 priority="1000"
                 mode="M108">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-261 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-261 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M108"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M108"/>
   <xsl:template match="@*|node()" priority="-2" mode="M108">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M108"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-262-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-262']"
                 priority="1001"
                 mode="M109">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-262'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-262'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-262'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M109"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-262']/fhir:answer/*"
                 priority="1000"
                 mode="M109">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-262 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-262 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M109"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M109"/>
   <xsl:template match="@*|node()" priority="-2" mode="M109">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M109"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-263-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-263']"
                 priority="1001"
                 mode="M110">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-263'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-263'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-263'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M110"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-263']/fhir:answer/*"
                 priority="1000"
                 mode="M110">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-263 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-263 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M110"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M110"/>
   <xsl:template match="@*|node()" priority="-2" mode="M110">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M110"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-264-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-264']"
                 priority="1001"
                 mode="M111">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-264'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-264'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-264'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M111"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-264']/fhir:answer/*"
                 priority="1000"
                 mode="M111">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-264 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-264 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M111"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M111"/>
   <xsl:template match="@*|node()" priority="-2" mode="M111">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M111"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-265-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-265']"
                 priority="1001"
                 mode="M112">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-265'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-265'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-265'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M112"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-265']/fhir:answer/*"
                 priority="1000"
                 mode="M112">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-265 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-265 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M112"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M112"/>
   <xsl:template match="@*|node()" priority="-2" mode="M112">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M112"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-266-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-266']"
                 priority="1001"
                 mode="M113">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-266'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-266'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-266'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M113"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-266']/fhir:answer/*"
                 priority="1000"
                 mode="M113">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-266 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-266 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M113"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M113"/>
   <xsl:template match="@*|node()" priority="-2" mode="M113">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M113"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-267-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-267']"
                 priority="1001"
                 mode="M114">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-267'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-267'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-267'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M114"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-267']/fhir:answer/*"
                 priority="1000"
                 mode="M114">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-267 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-267 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M114"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M114"/>
   <xsl:template match="@*|node()" priority="-2" mode="M114">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M114"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-268-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-268']"
                 priority="1001"
                 mode="M115">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-268'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-268'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-268'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M115"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-268']/fhir:answer/*"
                 priority="1000"
                 mode="M115">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M115"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M115"/>
   <xsl:template match="@*|node()" priority="-2" mode="M115">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M115"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-269-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-269']"
                 priority="1001"
                 mode="M116">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-269'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-269'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-269'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M116"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-269']/fhir:answer/*"
                 priority="1000"
                 mode="M116">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.27--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.27--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-269 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.27--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.27--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-269 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.27--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M116"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M116"/>
   <xsl:template match="@*|node()" priority="-2" mode="M116">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M116"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-270-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-270']"
                 priority="1001"
                 mode="M117">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-270'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-270'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-270'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M117"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-270']/fhir:answer/*"
                 priority="1000"
                 mode="M117">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-270 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-270 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M117"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M117"/>
   <xsl:template match="@*|node()" priority="-2" mode="M117">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M117"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-271-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-271']"
                 priority="1001"
                 mode="M118">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-271'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-271'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-271'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M118"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-271']/fhir:answer/*"
                 priority="1000"
                 mode="M118">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M118"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M118"/>
   <xsl:template match="@*|node()" priority="-2" mode="M118">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M118"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-272-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-272']"
                 priority="1001"
                 mode="M119">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-272'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-272'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-272'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M119"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-272']/fhir:answer/*"
                 priority="1000"
                 mode="M119">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M119"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M119"/>
   <xsl:template match="@*|node()" priority="-2" mode="M119">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M119"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-273-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-273']"
                 priority="1001"
                 mode="M120">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-273'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-273'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-273'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M120"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-273']/fhir:answer/*"
                 priority="1000"
                 mode="M120">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-273 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-273 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M120"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M120"/>
   <xsl:template match="@*|node()" priority="-2" mode="M120">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M120"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-274-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-274']"
                 priority="1001"
                 mode="M121">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-274'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-274'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-274'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M121"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-274']/fhir:answer/*"
                 priority="1000"
                 mode="M121">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-274 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-274 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M121"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M121"/>
   <xsl:template match="@*|node()" priority="-2" mode="M121">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M121"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-163-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']"
                 priority="1001"
                 mode="M122">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-163'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-163'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-163'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M122"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']/fhir:answer/*"
                 priority="1000"
                 mode="M122">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M122"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M122"/>
   <xsl:template match="@*|node()" priority="-2" mode="M122">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M122"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-164-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']"
                 priority="1001"
                 mode="M123">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-164'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-164'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-164'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M123"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']/fhir:answer/*"
                 priority="1000"
                 mode="M123">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-generic-dataelement-164 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-generic-dataelement-164 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M123"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M123"/>
   <xsl:template match="@*|node()" priority="-2" mode="M123">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M123"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-165-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']"
                 priority="1001"
                 mode="M124">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-165'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-165'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-165'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M124"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']/fhir:answer/*"
                 priority="1000"
                 mode="M124">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M124"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M124"/>
   <xsl:template match="@*|node()" priority="-2" mode="M124">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M124"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-166-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']"
                 priority="1001"
                 mode="M125">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-166'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-166'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-166'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M125"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']/fhir:answer/*"
                 priority="1000"
                 mode="M125">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M125"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M125"/>
   <xsl:template match="@*|node()" priority="-2" mode="M125">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M125"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-168-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']"
                 priority="1001"
                 mode="M126">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-168'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-168'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-168'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M126"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']/fhir:answer/*"
                 priority="1000"
                 mode="M126">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-generic-dataelement-168 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-generic-dataelement-168 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M126"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M126"/>
   <xsl:template match="@*|node()" priority="-2" mode="M126">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M126"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-169-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']"
                 priority="1001"
                 mode="M127">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-169'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-169'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-169'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M127"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']/fhir:answer/*"
                 priority="1000"
                 mode="M127">

		<!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M127"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M127"/>
   <xsl:template match="@*|node()" priority="-2" mode="M127">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M127"/>
   </xsl:template>
</xsl:stylesheet>
