<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:fhir="http://hl7.org/fhir"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


   <!--PROLOG-->
   <xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


   <!--KEYS AND FUNCTIONS-->


   <!--DEFAULT RULES-->


   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl" title="" schemaVersion="">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="http://hl7.org/fhir" prefix="fhir"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/XML/1998/namespace" prefix="xml"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-81</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-81</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M3"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-127</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-127</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M4"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-145</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-145</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M5"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-192</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-192</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M6"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-197</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-197</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M7"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-200</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-200</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M8"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-201</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-201</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M9"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-202</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-202</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M10"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-203</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-203</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M11"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-154</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-154</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M12"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-155</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-155</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M13"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-156</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-156</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M14"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-157</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-157</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M15"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-159</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-159</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M16"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-160</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-160</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M17"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-161</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-161</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M18"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-231</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-231</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M19"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-275</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-275</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M20"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-276</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-276</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M21"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-277</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-277</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M22"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-278</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-278</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M23"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-279</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-279</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M24"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-280</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-280</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M25"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-281</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-281</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M26"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-282</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-282</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M27"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-283</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-283</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M28"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-284</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-284</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M29"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-285</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-285</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M30"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-286</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-286</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M31"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-287</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-287</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M32"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-288</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-288</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M33"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-289</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-289</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M34"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-290</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-290</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M35"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-291</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-291</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M36"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-292</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-292</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M37"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-293</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-293</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M38"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-294</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-294</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M39"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-295</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-295</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M40"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-296</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-296</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M41"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-297</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-297</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M42"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-298</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-298</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M43"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-299</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-299</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M44"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-163</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-163</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M45"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-164</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-164</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M46"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-165</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-165</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M47"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-166</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-166</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M48"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-168</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-168</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M49"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-169</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-169</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M50"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


   <!--PATTERN onco-generic-dataelement-81-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-81']"
                 priority="1001"
                 mode="M3">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-81']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-81'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-81'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-81'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-81']/fhir:answer/*"
                 priority="1000"
                 mode="M3">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-81']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M3"/>
   <xsl:template match="@*|node()" priority="-2" mode="M3">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-127-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-127']"
                 priority="1001"
                 mode="M4">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-127']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-127'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-127'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-127'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-127']/fhir:answer/*"
                 priority="1000"
                 mode="M4">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-127']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M4"/>
   <xsl:template match="@*|node()" priority="-2" mode="M4">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-145-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-145']"
                 priority="1001"
                 mode="M5">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-145']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-145'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-145'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-145'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-145']/fhir:answer/*"
                 priority="1000"
                 mode="M5">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-145']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'value'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl" test="local-name(.) = 'value'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'value'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M5"/>
   <xsl:template match="@*|node()" priority="-2" mode="M5">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-192-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-192']"
                 priority="1001"
                 mode="M6">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-192']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-192'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-192'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-192'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-192']/fhir:answer/*"
                 priority="1000"
                 mode="M6">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-192']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M6"/>
   <xsl:template match="@*|node()" priority="-2" mode="M6">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-197-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-197']"
                 priority="1001"
                 mode="M7">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-197']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-197'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-197'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-197'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-197']/fhir:answer/*"
                 priority="1000"
                 mode="M7">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-197']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M7"/>
   <xsl:template match="@*|node()" priority="-2" mode="M7">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-200-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-200']"
                 priority="1001"
                 mode="M8">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-200']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-200'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-200'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-200'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-200']/fhir:answer/*"
                 priority="1000"
                 mode="M8">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-200']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M8"/>
   <xsl:template match="@*|node()" priority="-2" mode="M8">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-201-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-201']"
                 priority="1001"
                 mode="M9">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-201']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-201'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-201'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-201'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-201']/fhir:answer/*"
                 priority="1000"
                 mode="M9">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-201']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-201 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-201 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M9"/>
   <xsl:template match="@*|node()" priority="-2" mode="M9">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-202-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-202']"
                 priority="1001"
                 mode="M10">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-202']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-202'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-202'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-202'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-202']/fhir:answer/*"
                 priority="1000"
                 mode="M10">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-202']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-202 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-202 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M10"/>
   <xsl:template match="@*|node()" priority="-2" mode="M10">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-203-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-203']"
                 priority="1001"
                 mode="M11">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-203']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-203'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-203'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-203'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-203']/fhir:answer/*"
                 priority="1000"
                 mode="M11">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-203']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-203 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-203 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M11"/>
   <xsl:template match="@*|node()" priority="-2" mode="M11">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-154-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']"
                 priority="1001"
                 mode="M12">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-154'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-154'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-154'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']/fhir:answer/*"
                 priority="1000"
                 mode="M12">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M12"/>
   <xsl:template match="@*|node()" priority="-2" mode="M12">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-155-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']"
                 priority="1001"
                 mode="M13">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-155'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-155'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-155'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']/fhir:answer/*"
                 priority="1000"
                 mode="M13">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueDate'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueDate'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueDate'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M13"/>
   <xsl:template match="@*|node()" priority="-2" mode="M13">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-156-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']"
                 priority="1001"
                 mode="M14">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-156'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-156'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-156'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']/fhir:answer/*"
                 priority="1000"
                 mode="M14">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M14"/>
   <xsl:template match="@*|node()" priority="-2" mode="M14">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-157-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']"
                 priority="1001"
                 mode="M15">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-157'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-157'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-157'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']/fhir:answer/*"
                 priority="1000"
                 mode="M15">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-generic-dataelement-157 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-generic-dataelement-157 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M15"/>
   <xsl:template match="@*|node()" priority="-2" mode="M15">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-159-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-159']"
                 priority="1001"
                 mode="M16">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-159']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-159'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-159'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-159'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-159']/fhir:answer/*"
                 priority="1000"
                 mode="M16">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-159']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-generic-dataelement-159 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-generic-dataelement-159 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M16"/>
   <xsl:template match="@*|node()" priority="-2" mode="M16">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-160-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']"
                 priority="1001"
                 mode="M17">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-160'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-160'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-160'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']/fhir:answer/*"
                 priority="1000"
                 mode="M17">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueDate'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueDate'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueDate'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M17"/>
   <xsl:template match="@*|node()" priority="-2" mode="M17">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-161-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']"
                 priority="1001"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-161'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-161'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-161'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']/fhir:answer/*"
                 priority="1000"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M18"/>
   <xsl:template match="@*|node()" priority="-2" mode="M18">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-231-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']"
                 priority="1001"
                 mode="M19">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-231'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-231'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-231'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']/fhir:answer/*"
                 priority="1000"
                 mode="M19">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M19"/>
   <xsl:template match="@*|node()" priority="-2" mode="M19">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-275-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-275']"
                 priority="1001"
                 mode="M20">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-275']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-275'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-275'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-275'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-275']/fhir:answer/*"
                 priority="1000"
                 mode="M20">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-275']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M20"/>
   <xsl:template match="@*|node()" priority="-2" mode="M20">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-276-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-276']"
                 priority="1001"
                 mode="M21">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-276']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-276'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-276'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-276'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-276']/fhir:answer/*"
                 priority="1000"
                 mode="M21">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-276']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M21"/>
   <xsl:template match="@*|node()" priority="-2" mode="M21">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-277-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-277']"
                 priority="1001"
                 mode="M22">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-277']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-277'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-277'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-277'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-277']/fhir:answer/*"
                 priority="1000"
                 mode="M22">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-277']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-277 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-277 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M22"/>
   <xsl:template match="@*|node()" priority="-2" mode="M22">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-278-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-278']"
                 priority="1001"
                 mode="M23">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-278']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-278'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-278'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-278'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-278']/fhir:answer/*"
                 priority="1000"
                 mode="M23">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-278']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-278 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-278 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M23"/>
   <xsl:template match="@*|node()" priority="-2" mode="M23">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-279-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-279']"
                 priority="1001"
                 mode="M24">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-279']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-279'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-279'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-279'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-279']/fhir:answer/*"
                 priority="1000"
                 mode="M24">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-279']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-279 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-279 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M24"/>
   <xsl:template match="@*|node()" priority="-2" mode="M24">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-280-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-280']"
                 priority="1001"
                 mode="M25">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-280']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-280'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-280'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-280'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-280']/fhir:answer/*"
                 priority="1000"
                 mode="M25">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-280']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-280 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-280 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M25"/>
   <xsl:template match="@*|node()" priority="-2" mode="M25">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-281-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-281']"
                 priority="1001"
                 mode="M26">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-281']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-281'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-281'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-281'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-281']/fhir:answer/*"
                 priority="1000"
                 mode="M26">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-281']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.35--20150714070650', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.35--20150714070650</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-281 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.35--20150714070650.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.35--20150714070650</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-281 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.35--20150714070650.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M26"/>
   <xsl:template match="@*|node()" priority="-2" mode="M26">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-282-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-282']"
                 priority="1001"
                 mode="M27">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-282']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-282'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-282'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-282'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-282']/fhir:answer/*"
                 priority="1000"
                 mode="M27">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-282']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M27"/>
   <xsl:template match="@*|node()" priority="-2" mode="M27">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-283-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-283']"
                 priority="1001"
                 mode="M28">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-283']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-283'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-283'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-283'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-283']/fhir:answer/*"
                 priority="1000"
                 mode="M28">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-283']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-283 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-283 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M28"/>
   <xsl:template match="@*|node()" priority="-2" mode="M28">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-284-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-284']"
                 priority="1001"
                 mode="M29">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-284']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-284'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-284'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-284'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-284']/fhir:answer/*"
                 priority="1000"
                 mode="M29">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-284']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-284 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-284 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M29"/>
   <xsl:template match="@*|node()" priority="-2" mode="M29">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-285-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-285']"
                 priority="1001"
                 mode="M30">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-285']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-285'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-285'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-285'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-285']/fhir:answer/*"
                 priority="1000"
                 mode="M30">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-285']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-285 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-285 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M30"/>
   <xsl:template match="@*|node()" priority="-2" mode="M30">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-286-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-286']"
                 priority="1001"
                 mode="M31">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-286']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-286'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-286'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-286'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-286']/fhir:answer/*"
                 priority="1000"
                 mode="M31">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-286']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-286 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-286 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.21--20150617153451.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M31"/>
   <xsl:template match="@*|node()" priority="-2" mode="M31">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-287-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-287']"
                 priority="1001"
                 mode="M32">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-287']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-287'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-287'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-287'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-287']/fhir:answer/*"
                 priority="1000"
                 mode="M32">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-287']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M32"/>
   <xsl:template match="@*|node()" priority="-2" mode="M32">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-288-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-288']"
                 priority="1001"
                 mode="M33">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-288']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-288'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-288'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-288'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-288']/fhir:answer/*"
                 priority="1000"
                 mode="M33">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-288']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-288 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-288 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M33"/>
   <xsl:template match="@*|node()" priority="-2" mode="M33">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-289-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-289']"
                 priority="1001"
                 mode="M34">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-289']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-289'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-289'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-289'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-289']/fhir:answer/*"
                 priority="1000"
                 mode="M34">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-289']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-289 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-289 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M34"/>
   <xsl:template match="@*|node()" priority="-2" mode="M34">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-290-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-290']"
                 priority="1001"
                 mode="M35">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-290']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-290'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-290'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-290'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-290']/fhir:answer/*"
                 priority="1000"
                 mode="M35">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-290']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-290 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-290 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M35"/>
   <xsl:template match="@*|node()" priority="-2" mode="M35">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-291-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-291']"
                 priority="1001"
                 mode="M36">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-291']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-291'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-291'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-291'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-291']/fhir:answer/*"
                 priority="1000"
                 mode="M36">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-291']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-291 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-291 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M36"/>
   <xsl:template match="@*|node()" priority="-2" mode="M36">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-292-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-292']"
                 priority="1001"
                 mode="M37">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-292']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-292'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-292'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-292'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-292']/fhir:answer/*"
                 priority="1000"
                 mode="M37">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-292']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-292 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-292 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M37"/>
   <xsl:template match="@*|node()" priority="-2" mode="M37">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-293-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-293']"
                 priority="1001"
                 mode="M38">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-293']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-293'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-293'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-293'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-293']/fhir:answer/*"
                 priority="1000"
                 mode="M38">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-293']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-293 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-293 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M38"/>
   <xsl:template match="@*|node()" priority="-2" mode="M38">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-294-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-294']"
                 priority="1001"
                 mode="M39">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-294']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-294'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-294'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-294'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-294']/fhir:answer/*"
                 priority="1000"
                 mode="M39">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-294']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-294 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-294 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.6--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M39"/>
   <xsl:template match="@*|node()" priority="-2" mode="M39">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-295-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-295']"
                 priority="1001"
                 mode="M40">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-295']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-295'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-295'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-295'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-295']/fhir:answer/*"
                 priority="1000"
                 mode="M40">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-295']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M40"/>
   <xsl:template match="@*|node()" priority="-2" mode="M40">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-296-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-296']"
                 priority="1001"
                 mode="M41">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-296']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-296'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-296'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-296'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-296']/fhir:answer/*"
                 priority="1000"
                 mode="M41">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-296']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-296 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-296 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.59--20160217151411.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M41"/>
   <xsl:template match="@*|node()" priority="-2" mode="M41">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-297-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-297']"
                 priority="1001"
                 mode="M42">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-297']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-297'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-297'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-297'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-297']/fhir:answer/*"
                 priority="1000"
                 mode="M42">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-297']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.27--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.27--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-297 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.27--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.27--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-297 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.27--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M42"/>
   <xsl:template match="@*|node()" priority="-2" mode="M42">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-298-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-298']"
                 priority="1001"
                 mode="M43">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-298']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-298'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-298'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-298'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-298']/fhir:answer/*"
                 priority="1000"
                 mode="M43">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-298']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-298 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-298 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M43"/>
   <xsl:template match="@*|node()" priority="-2" mode="M43">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-299-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-299']"
                 priority="1001"
                 mode="M44">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-299']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-299'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-299'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-299'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M44"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-299']/fhir:answer/*"
                 priority="1000"
                 mode="M44">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-299']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-299 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-299 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M44"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M44"/>
   <xsl:template match="@*|node()" priority="-2" mode="M44">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M44"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-163-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']"
                 priority="1001"
                 mode="M45">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-163'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-163'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-163'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M45"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']/fhir:answer/*"
                 priority="1000"
                 mode="M45">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M45"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M45"/>
   <xsl:template match="@*|node()" priority="-2" mode="M45">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M45"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-164-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']"
                 priority="1001"
                 mode="M46">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-164'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-164'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-164'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M46"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']/fhir:answer/*"
                 priority="1000"
                 mode="M46">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-generic-dataelement-164 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-generic-dataelement-164 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M46"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M46"/>
   <xsl:template match="@*|node()" priority="-2" mode="M46">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M46"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-165-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']"
                 priority="1001"
                 mode="M47">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-165'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-165'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-165'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M47"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']/fhir:answer/*"
                 priority="1000"
                 mode="M47">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M47"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M47"/>
   <xsl:template match="@*|node()" priority="-2" mode="M47">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M47"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-166-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']"
                 priority="1001"
                 mode="M48">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-166'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-166'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-166'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M48"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']/fhir:answer/*"
                 priority="1000"
                 mode="M48">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M48"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M48"/>
   <xsl:template match="@*|node()" priority="-2" mode="M48">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M48"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-168-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']"
                 priority="1001"
                 mode="M49">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-168'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-168'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-168'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M49"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']/fhir:answer/*"
                 priority="1000"
                 mode="M49">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-generic-dataelement-168 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-generic-dataelement-168 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M49"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M49"/>
   <xsl:template match="@*|node()" priority="-2" mode="M49">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M49"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-169-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']"
                 priority="1001"
                 mode="M50">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-169'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-169'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-169'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M50"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']/fhir:answer/*"
                 priority="1000"
                 mode="M50">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M50"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M50"/>
   <xsl:template match="@*|node()" priority="-2" mode="M50">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M50"/>
   </xsl:template>
</xsl:stylesheet>
