<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:fhir="http://hl7.org/fhir"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


   <!--PROLOG-->
   <xsl:output xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
               method="xml"
               omit-xml-declaration="no"
               standalone="yes"
               indent="yes"/>

   <!--XSD TYPES FOR XSLT2-->


   <!--KEYS AND FUNCTIONS-->


   <!--DEFAULT RULES-->


   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <svrl:schematron-output xmlns:svrl="http://purl.oclc.org/dsdl/svrl" title="" schemaVersion="">
         <xsl:comment>
            <xsl:value-of select="$archiveDirParameter"/>   
		 <xsl:value-of select="$archiveNameParameter"/>  
		 <xsl:value-of select="$fileNameParameter"/>  
		 <xsl:value-of select="$fileDirParameter"/>
         </xsl:comment>
         <svrl:ns-prefix-in-attribute-values uri="http://hl7.org/fhir" prefix="fhir"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/2001/XMLSchema-instance" prefix="xsi"/>
         <svrl:ns-prefix-in-attribute-values uri="http://www.w3.org/XML/1998/namespace" prefix="xml"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-154</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-154</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M3"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-155</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-155</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M4"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-156</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-156</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M5"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-157</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-157</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M6"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-160</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-160</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M7"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-161</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-161</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M8"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-231</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-231</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M9"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-246</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-246</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M10"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-260</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-260</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M11"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-264</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-264</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M12"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-300</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-300</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M13"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-301</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-301</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M14"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-302</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-302</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M15"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-303</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-303</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M16"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-304</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-304</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M17"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-305</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-305</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M18"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-306</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-306</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M19"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-307</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-307</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M20"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-308</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-308</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M21"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-309</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-309</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M22"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-310</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-310</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M23"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-311</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-311</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M24"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-312</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-312</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M25"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-313</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-313</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M26"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-314</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-314</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M27"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-315</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-315</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M28"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-316</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-316</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M29"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-317</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-317</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M30"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-318</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-318</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M31"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-319</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-319</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M32"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-320</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-320</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M33"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-321</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-321</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M34"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-322</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-322</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M35"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-323</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-323</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M36"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-324</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-324</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M37"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-325</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-325</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M38"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-326</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-326</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M39"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-327</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-327</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M40"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-328</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-328</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M41"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-329</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-329</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M42"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-330</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-330</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M43"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-331</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-331</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M44"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-332</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-332</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M45"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-333</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-333</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M46"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-163</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-163</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M47"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-383</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-383</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M48"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-412</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-412</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M49"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-413</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-413</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M50"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-164</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-164</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M51"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-165</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-165</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M52"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-166</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-166</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M53"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-168</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-168</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M54"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-169</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-169</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M55"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-generic-dataelement-171</xsl:attribute>
            <xsl:attribute name="name">onco-generic-dataelement-171</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M56"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-420</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-420</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M57"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-422</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-422</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M58"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-424</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-424</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M59"/>
         <svrl:active-pattern>
            <xsl:attribute name="document">
               <xsl:value-of select="document-uri(/)"/>
            </xsl:attribute>
            <xsl:attribute name="id">onco-mamma-dataelement-426</xsl:attribute>
            <xsl:attribute name="name">onco-mamma-dataelement-426</xsl:attribute>
            <xsl:apply-templates/>
         </svrl:active-pattern>
         <xsl:apply-templates select="/" mode="M60"/>
      </svrl:schematron-output>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


   <!--PATTERN onco-generic-dataelement-154-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']"
                 priority="1001"
                 mode="M3">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-154'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-154'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-154'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']/fhir:answer/*"
                 priority="1000"
                 mode="M3">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-154']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M3"/>
   <xsl:template match="@*|node()" priority="-2" mode="M3">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M3"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-155-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']"
                 priority="1001"
                 mode="M4">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-155'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-155'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-155'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']/fhir:answer/*"
                 priority="1000"
                 mode="M4">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-155']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueDate'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueDate'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueDate'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M4"/>
   <xsl:template match="@*|node()" priority="-2" mode="M4">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M4"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-156-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']"
                 priority="1001"
                 mode="M5">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-156'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-156'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-156'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']/fhir:answer/*"
                 priority="1000"
                 mode="M5">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-156']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M5"/>
   <xsl:template match="@*|node()" priority="-2" mode="M5">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M5"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-157-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']"
                 priority="1001"
                 mode="M6">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-157'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-157'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-157'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']/fhir:answer/*"
                 priority="1000"
                 mode="M6">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-157']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-generic-dataelement-157 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-generic-dataelement-157 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.21--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M6"/>
   <xsl:template match="@*|node()" priority="-2" mode="M6">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M6"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-160-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']"
                 priority="1001"
                 mode="M7">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-160'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-160'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-160'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']/fhir:answer/*"
                 priority="1000"
                 mode="M7">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-160']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueDate'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueDate'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueDate'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M7"/>
   <xsl:template match="@*|node()" priority="-2" mode="M7">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M7"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-161-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']"
                 priority="1001"
                 mode="M8">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-161'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-161'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-161'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']/fhir:answer/*"
                 priority="1000"
                 mode="M8">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-161']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M8"/>
   <xsl:template match="@*|node()" priority="-2" mode="M8">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M8"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-231-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']"
                 priority="1001"
                 mode="M9">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-231'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-231'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-231'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']/fhir:answer/*"
                 priority="1000"
                 mode="M9">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-231']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M9"/>
   <xsl:template match="@*|node()" priority="-2" mode="M9">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M9"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-246-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-246']"
                 priority="1001"
                 mode="M10">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-246']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-246'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-246'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-246'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-246']/fhir:answer/*"
                 priority="1000"
                 mode="M10">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-246']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M10"/>
   <xsl:template match="@*|node()" priority="-2" mode="M10">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M10"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-260-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-260']"
                 priority="1001"
                 mode="M11">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-260']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-260'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-260'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-260'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-260']/fhir:answer/*"
                 priority="1000"
                 mode="M11">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-260']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M11"/>
   <xsl:template match="@*|node()" priority="-2" mode="M11">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M11"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-264-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-264']"
                 priority="1001"
                 mode="M12">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-264']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-264'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-264'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-264'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-264']/fhir:answer/*"
                 priority="1000"
                 mode="M12">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-264']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-264 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-264 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M12"/>
   <xsl:template match="@*|node()" priority="-2" mode="M12">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M12"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-300-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-300']"
                 priority="1001"
                 mode="M13">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-300']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-300'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-300'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-300'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-300']/fhir:answer/*"
                 priority="1000"
                 mode="M13">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-300']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M13"/>
   <xsl:template match="@*|node()" priority="-2" mode="M13">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M13"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-301-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-301']"
                 priority="1001"
                 mode="M14">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-301']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-301'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-301'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-301'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-301']/fhir:answer/*"
                 priority="1000"
                 mode="M14">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-301']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M14"/>
   <xsl:template match="@*|node()" priority="-2" mode="M14">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M14"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-302-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-302']"
                 priority="1001"
                 mode="M15">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-302']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-302'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-302'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-302'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-302']/fhir:answer/*"
                 priority="1000"
                 mode="M15">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-302']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-302 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-302 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M15"/>
   <xsl:template match="@*|node()" priority="-2" mode="M15">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M15"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-303-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-303']"
                 priority="1001"
                 mode="M16">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-303']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-303'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-303'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-303'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-303']/fhir:answer/*"
                 priority="1000"
                 mode="M16">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-303']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-303 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-303 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.36--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M16"/>
   <xsl:template match="@*|node()" priority="-2" mode="M16">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M16"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-304-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-304']"
                 priority="1001"
                 mode="M17">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-304']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-304'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-304'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-304'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-304']/fhir:answer/*"
                 priority="1000"
                 mode="M17">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-304']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M17"/>
   <xsl:template match="@*|node()" priority="-2" mode="M17">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M17"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-305-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-305']"
                 priority="1001"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-305']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-305'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-305'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-305'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-305']/fhir:answer/*"
                 priority="1000"
                 mode="M18">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-305']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-305 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-305 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M18"/>
   <xsl:template match="@*|node()" priority="-2" mode="M18">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M18"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-306-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-306']"
                 priority="1001"
                 mode="M19">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-306']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-306'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-306'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-306'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-306']/fhir:answer/*"
                 priority="1000"
                 mode="M19">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-306']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-306 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-306 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.56--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M19"/>
   <xsl:template match="@*|node()" priority="-2" mode="M19">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M19"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-307-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-307']"
                 priority="1001"
                 mode="M20">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-307']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-307'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-307'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-307'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-307']/fhir:answer/*"
                 priority="1000"
                 mode="M20">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-307']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-307 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-307 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.45--20170223104440.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M20"/>
   <xsl:template match="@*|node()" priority="-2" mode="M20">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M20"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-308-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-308']"
                 priority="1001"
                 mode="M21">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-308']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-308'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-308'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-308'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-308']/fhir:answer/*"
                 priority="1000"
                 mode="M21">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-308']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.13--20160104144120', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.13--20160104144120</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-308 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.13--20160104144120.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.13--20160104144120</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-308 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.13--20160104144120.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M21"/>
   <xsl:template match="@*|node()" priority="-2" mode="M21">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M21"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-309-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-309']"
                 priority="1001"
                 mode="M22">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-309']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-309'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-309'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-309'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-309']/fhir:answer/*"
                 priority="1000"
                 mode="M22">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-309']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.40--20160817135741', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.40--20160817135741</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-309 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.40--20160817135741.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.40--20160817135741</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-309 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.40--20160817135741.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M22"/>
   <xsl:template match="@*|node()" priority="-2" mode="M22">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M22"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-310-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-310']"
                 priority="1001"
                 mode="M23">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-310']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-310'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-310'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-310'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-310']/fhir:answer/*"
                 priority="1000"
                 mode="M23">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-310']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.32--20151123081343', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.32--20151123081343</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-310 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.32--20151123081343.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.32--20151123081343</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-310 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.32--20151123081343.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M23"/>
   <xsl:template match="@*|node()" priority="-2" mode="M23">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M23"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-311-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-311']"
                 priority="1001"
                 mode="M24">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-311']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-311'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-311'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-311'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-311']/fhir:answer/*"
                 priority="1000"
                 mode="M24">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-311']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M24"/>
   <xsl:template match="@*|node()" priority="-2" mode="M24">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M24"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-312-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-312']"
                 priority="1001"
                 mode="M25">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-312']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-312'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-312'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-312'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-312']/fhir:answer/*"
                 priority="1000"
                 mode="M25">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-312']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M25"/>
   <xsl:template match="@*|node()" priority="-2" mode="M25">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M25"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-313-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-313']"
                 priority="1001"
                 mode="M26">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-313']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-313'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-313'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-313'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-313']/fhir:answer/*"
                 priority="1000"
                 mode="M26">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-313']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M26"/>
   <xsl:template match="@*|node()" priority="-2" mode="M26">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M26"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-314-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-314']"
                 priority="1001"
                 mode="M27">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-314']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-314'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-314'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-314'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-314']/fhir:answer/*"
                 priority="1000"
                 mode="M27">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-314']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-314 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-314 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.51--20150605091504.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M27"/>
   <xsl:template match="@*|node()" priority="-2" mode="M27">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M27"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-315-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-315']"
                 priority="1001"
                 mode="M28">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-315']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-315'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-315'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-315'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-315']/fhir:answer/*"
                 priority="1000"
                 mode="M28">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-315']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M28"/>
   <xsl:template match="@*|node()" priority="-2" mode="M28">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M28"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-316-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-316']"
                 priority="1001"
                 mode="M29">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-316']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-316'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-316'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-316'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-316']/fhir:answer/*"
                 priority="1000"
                 mode="M29">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-316']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-316 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-316 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.48--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M29"/>
   <xsl:template match="@*|node()" priority="-2" mode="M29">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M29"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-317-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-317']"
                 priority="1001"
                 mode="M30">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-317']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-317'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-317'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-317'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-317']/fhir:answer/*"
                 priority="1000"
                 mode="M30">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-317']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-317 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-317 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M30"/>
   <xsl:template match="@*|node()" priority="-2" mode="M30">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M30"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-318-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-318']"
                 priority="1001"
                 mode="M31">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-318']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-318'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-318'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-318'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-318']/fhir:answer/*"
                 priority="1000"
                 mode="M31">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-318']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-318 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-318 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M31"/>
   <xsl:template match="@*|node()" priority="-2" mode="M31">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M31"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-319-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-319']"
                 priority="1001"
                 mode="M32">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-319']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-319'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-319'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-319'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-319']/fhir:answer/*"
                 priority="1000"
                 mode="M32">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-319']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-319 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-319 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M32"/>
   <xsl:template match="@*|node()" priority="-2" mode="M32">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M32"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-320-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-320']"
                 priority="1001"
                 mode="M33">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-320']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-320'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-320'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-320'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-320']/fhir:answer/*"
                 priority="1000"
                 mode="M33">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-320']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueInteger'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueInteger'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueInteger'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M33"/>
   <xsl:template match="@*|node()" priority="-2" mode="M33">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M33"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-321-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-321']"
                 priority="1001"
                 mode="M34">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-321']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-321'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-321'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-321'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-321']/fhir:answer/*"
                 priority="1000"
                 mode="M34">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-321']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueInteger'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueInteger'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueInteger'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M34"/>
   <xsl:template match="@*|node()" priority="-2" mode="M34">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M34"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-322-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-322']"
                 priority="1001"
                 mode="M35">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-322']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-322'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-322'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-322'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-322']/fhir:answer/*"
                 priority="1000"
                 mode="M35">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-322']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueInteger'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueInteger'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueInteger'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M35"/>
   <xsl:template match="@*|node()" priority="-2" mode="M35">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M35"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-323-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-323']"
                 priority="1001"
                 mode="M36">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-323']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-323'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-323'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-323'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-323']/fhir:answer/*"
                 priority="1000"
                 mode="M36">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-323']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueInteger'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueInteger'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueInteger'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M36"/>
   <xsl:template match="@*|node()" priority="-2" mode="M36">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M36"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-324-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-324']"
                 priority="1001"
                 mode="M37">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-324']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-324'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-324'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-324'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-324']/fhir:answer/*"
                 priority="1000"
                 mode="M37">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-324']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.58--20151105100811', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.58--20151105100811</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-324 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.58--20151105100811.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.58--20151105100811</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-324 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.58--20151105100811.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M37"/>
   <xsl:template match="@*|node()" priority="-2" mode="M37">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M37"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-325-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-325']"
                 priority="1001"
                 mode="M38">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-325']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-325'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-325'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-325'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-325']/fhir:answer/*"
                 priority="1000"
                 mode="M38">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-325']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.58--20151105100811', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.58--20151105100811</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-325 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.58--20151105100811.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.58--20151105100811</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-325 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.58--20151105100811.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M38"/>
   <xsl:template match="@*|node()" priority="-2" mode="M38">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M38"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-326-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-326']"
                 priority="1001"
                 mode="M39">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-326']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-326'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-326'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-326'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-326']/fhir:answer/*"
                 priority="1000"
                 mode="M39">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-326']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.19--20160818185515', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.19--20160818185515</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-326 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.19--20160818185515.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.19--20160818185515</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-326 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.19--20160818185515.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M39"/>
   <xsl:template match="@*|node()" priority="-2" mode="M39">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M39"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-327-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-327']"
                 priority="1001"
                 mode="M40">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-327']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-327'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-327'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-327'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-327']/fhir:answer/*"
                 priority="1000"
                 mode="M40">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-327']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.24--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.24--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-327 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.24--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.24--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-327 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.24--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M40"/>
   <xsl:template match="@*|node()" priority="-2" mode="M40">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M40"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-328-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-328']"
                 priority="1001"
                 mode="M41">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-328']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-328'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-328'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-328'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-328']/fhir:answer/*"
                 priority="1000"
                 mode="M41">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-328']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M41"/>
   <xsl:template match="@*|node()" priority="-2" mode="M41">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M41"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-329-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-329']"
                 priority="1001"
                 mode="M42">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-329']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-329'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-329'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-329'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-329']/fhir:answer/*"
                 priority="1000"
                 mode="M42">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-329']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-329 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-329 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.62--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M42"/>
   <xsl:template match="@*|node()" priority="-2" mode="M42">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M42"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-330-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-330']"
                 priority="1001"
                 mode="M43">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-330']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-330'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-330'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-330'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-330']/fhir:answer/*"
                 priority="1000"
                 mode="M43">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-330']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-330 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-330 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.16--20150707093029.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M43"/>
   <xsl:template match="@*|node()" priority="-2" mode="M43">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M43"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-331-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-331']"
                 priority="1001"
                 mode="M44">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-331']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-331'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-331'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-331'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M44"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-331']/fhir:answer/*"
                 priority="1000"
                 mode="M44">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-331']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.10--20150603180139', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.10--20150603180139</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-331 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.10--20150603180139.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.10--20150603180139</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-331 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.10--20150603180139.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M44"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M44"/>
   <xsl:template match="@*|node()" priority="-2" mode="M44">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M44"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-332-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-332']"
                 priority="1001"
                 mode="M45">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-332']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-332'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-332'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-332'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M45"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-332']/fhir:answer/*"
                 priority="1000"
                 mode="M45">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-332']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.7--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.7--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-332 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.7--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.7--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-332 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.7--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M45"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M45"/>
   <xsl:template match="@*|node()" priority="-2" mode="M45">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M45"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-333-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-333']"
                 priority="1001"
                 mode="M46">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-333']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-333'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-333'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-333'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M46"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-333']/fhir:answer/*"
                 priority="1000"
                 mode="M46">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-333']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-333 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-333 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M46"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M46"/>
   <xsl:template match="@*|node()" priority="-2" mode="M46">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M46"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-163-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']"
                 priority="1001"
                 mode="M47">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-163'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-163'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-163'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M47"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']/fhir:answer/*"
                 priority="1000"
                 mode="M47">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-163']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M47"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M47"/>
   <xsl:template match="@*|node()" priority="-2" mode="M47">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M47"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-383-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-383']"
                 priority="1001"
                 mode="M48">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-383']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-383'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-383'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-383'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M48"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-383']/fhir:answer/*"
                 priority="1000"
                 mode="M48">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-383']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M48"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M48"/>
   <xsl:template match="@*|node()" priority="-2" mode="M48">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M48"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-412-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-412']"
                 priority="1001"
                 mode="M49">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-412']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-412'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-412'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-412'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M49"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-412']/fhir:answer/*"
                 priority="1000"
                 mode="M49">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-412']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M49"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M49"/>
   <xsl:template match="@*|node()" priority="-2" mode="M49">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M49"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-413-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-413']"
                 priority="1001"
                 mode="M50">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-413']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-413'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-413'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-413'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M50"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-413']/fhir:answer/*"
                 priority="1000"
                 mode="M50">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-413']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueQuantity'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueQuantity'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueQuantity'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M50"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M50"/>
   <xsl:template match="@*|node()" priority="-2" mode="M50">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M50"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-164-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']"
                 priority="1001"
                 mode="M51">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-164'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-164'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-164'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M51"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']/fhir:answer/*"
                 priority="1000"
                 mode="M51">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-164']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-generic-dataelement-164 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-generic-dataelement-164 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M51"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M51"/>
   <xsl:template match="@*|node()" priority="-2" mode="M51">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M51"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-165-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']"
                 priority="1001"
                 mode="M52">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-165'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-165'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-165'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M52"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']/fhir:answer/*"
                 priority="1000"
                 mode="M52">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-165']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M52"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M52"/>
   <xsl:template match="@*|node()" priority="-2" mode="M52">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M52"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-166-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']"
                 priority="1001"
                 mode="M53">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-166'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-166'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-166'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M53"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']/fhir:answer/*"
                 priority="1000"
                 mode="M53">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-166']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M53"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M53"/>
   <xsl:template match="@*|node()" priority="-2" mode="M53">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M53"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-168-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']"
                 priority="1001"
                 mode="M54">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-168'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-168'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-168'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M54"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']/fhir:answer/*"
                 priority="1000"
                 mode="M54">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-168']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-generic-dataelement-168 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-generic-dataelement-168 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.8--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M54"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M54"/>
   <xsl:template match="@*|node()" priority="-2" mode="M54">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M54"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-169-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']"
                 priority="1001"
                 mode="M55">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-169'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-169'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-169'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M55"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']/fhir:answer/*"
                 priority="1000"
                 mode="M55">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-169']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueString'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueString'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueString'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M55"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M55"/>
   <xsl:template match="@*|node()" priority="-2" mode="M55">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M55"/>
   </xsl:template>

   <!--PATTERN onco-generic-dataelement-171-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-171']"
                 priority="1001"
                 mode="M56">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-171']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-171'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-171'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-generic-dataelement-171'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M56"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-171']/fhir:answer/*"
                 priority="1000"
                 mode="M56">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-generic-dataelement-171']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M56"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M56"/>
   <xsl:template match="@*|node()" priority="-2" mode="M56">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M56"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-420-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-420']"
                 priority="1001"
                 mode="M57">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-420']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-420'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-420'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-420'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M57"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-420']/fhir:answer/*"
                 priority="1000"
                 mode="M57">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-420']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M57"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M57"/>
   <xsl:template match="@*|node()" priority="-2" mode="M57">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M57"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-422-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-422']"
                 priority="1001"
                 mode="M58">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-422']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-422'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-422'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-422'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M58"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-422']/fhir:answer/*"
                 priority="1000"
                 mode="M58">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-422']/fhir:answer/*"/>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M58"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M58"/>
   <xsl:template match="@*|node()" priority="-2" mode="M58">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M58"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-424-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-424']"
                 priority="1001"
                 mode="M59">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-424']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-424'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-424'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-424'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M59"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-424']/fhir:answer/*"
                 priority="1000"
                 mode="M59">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-424']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-424 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-424 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.1.11.3--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M59"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M59"/>
   <xsl:template match="@*|node()" priority="-2" mode="M59">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M59"/>
   </xsl:template>

   <!--PATTERN onco-mamma-dataelement-426-->


	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-426']"
                 priority="1001"
                 mode="M60">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-426']"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-426'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:definition/@value = 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-426'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Definition <value-of xmlns="http://hl7.org/fhir"
                            xmlns:sch="http://purl.oclc.org/dsdl/schematron"
                            select="fhir:definition/@value"/> must be 'http://www.iknl.nl/fhir/DataElement/onco-mamma-dataelement-426'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M60"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-426']/fhir:answer/*"
                 priority="1000"
                 mode="M60">
      <svrl:fired-rule xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                       context="//fhir:item[fhir:linkId/@value='onco-mamma-dataelement-426']/fhir:answer/*"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="local-name(.) = 'valueCoding'"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="local-name(.) = 'valueCoding'">
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>Answer must be of type 'valueCoding'.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="valueset"
                    select="doc(concat('../ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.26--20150530000000', '.xml'))"/>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:code/@value = $valueset//fhir:contains/fhir:code/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.26--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                Code <xsl:text/>
                  <xsl:value-of select="fhir:code/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-426 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.26--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT -->
      <xsl:choose>
         <xsl:when test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value"/>
         <xsl:otherwise>
            <svrl:failed-assert xmlns:svrl="http://purl.oclc.org/dsdl/svrl"
                                test="fhir:system/@value = $valueset//fhir:contains/fhir:system/@value">
               <xsl:attribute name="see">http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.26--20150530000000</xsl:attribute>
               <xsl:attribute name="location">
                  <xsl:apply-templates select="." mode="schematron-select-full-path"/>
               </xsl:attribute>
               <svrl:text>
                System <xsl:text/>
                  <xsl:value-of select="fhir:system/@value"/>
                  <xsl:text/> of onco-mamma-dataelement-426 must be from http://decor.nictiz.nl/fhir/ValueSet/2.16.840.1.113883.2.4.3.11.31.1.77.2.11.26--20150530000000.</svrl:text>
            </svrl:failed-assert>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M60"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M60"/>
   <xsl:template match="@*|node()" priority="-2" mode="M60">
      <xsl:apply-templates select="*|comment()|processing-instruction()" mode="M60"/>
   </xsl:template>
</xsl:stylesheet>
